==> sundr-model-0.103.1-sources.jar: io/sundr/model/PrimitiveRefFluent.java <==
package io.sundr.model;

import java.lang.Object;
import java.lang.String;
import java.lang.SuppressWarnings;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PrimitiveRefFluent<A extends PrimitiveRefFluent<A>> extends TypeRefFluent<A> {
  public PrimitiveRefFluent() {
  }

  public PrimitiveRefFluent(PrimitiveRef instance) {
    this.copyInstance(instance);
  }

  private String name;
  private int dimensions;

  protected void copyInstance(PrimitiveRef instance) {
    if (instance != null) {
      this.withName(instance.getName());
      this.withDimensions(instance.getDimensions());
      this.withAttributes(instance.getAttributes());
    }
  }

  public String getName() {
    return this.name;
  }

  public A withName(String name) {
    this.name = name;
    return (A) this;
  }

  public boolean hasName() {
    return this.name != null;
  }

  public int getDimensions() {
    return this.dimensions;
  }

  public A withDimensions(int dimensions) {
    this.dimensions = dimensions;
    return (A) this;
  }

  public boolean hasDimensions() {
    return true;
  }

  public boolean equals(Object o) {
    if (this == o)
      return true;
    if (o == null || getClass() != o.getClass())
      return false;
    if (!super.equals(o))
      return false;
    PrimitiveRefFluent that = (PrimitiveRefFluent) o;
    if (!java.util.Objects.equals(name, that.name))
      return false;
    if (dimensions != that.dimensions)
      return false;
    return true;
  }

  public int hashCode() {
    return java.util.Objects.hash(name, dimensions, super.hashCode());
  }

  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) {
      sb.append("name:");
      sb.append(name + ",");
    }
    sb.append("dimensions:");
    sb.append(dimensions);
    sb.append("}");
    return sb.toString();
  }

}

==> sundr-model-0.230.2-sources.jar: io/sundr/model/PrimitiveRefFluent.java <==
package io.sundr.model;

import java.lang.Object;
import java.lang.String;
import java.lang.StringBuilder;
import java.lang.SuppressWarnings;
import java.util.Objects;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PrimitiveRefFluent<A extends io.sundr.model.PrimitiveRefFluent<A>> extends TypeRefFluent<A> {

  private int dimensions;
  private String name;

  public PrimitiveRefFluent() {
  }

  public PrimitiveRefFluent(PrimitiveRef instance) {
    this.copyInstance(instance);
  }

  protected void copyInstance(PrimitiveRef instance) {
    if (instance != null) {
      this.withName(instance.getName());
      this.withDimensions(instance.getDimensions());
      this.withAttributes(instance.getAttributes());
    }
  }

  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || this.getClass() != o.getClass()) {
      return false;
    }
    if (!(super.equals(o))) {
      return false;
    }
    PrimitiveRefFluent that = (PrimitiveRefFluent) o;
    if (!(Objects.equals(name, that.name))) {
      return false;
    }
    if (dimensions != that.dimensions) {
      return false;
    }
    return true;
  }

  public int getDimensions() {
    return this.dimensions;
  }

  public String getName() {
    return this.name;
  }

  public boolean hasDimensions() {
    return true;
  }

  public boolean hasName() {
    return this.name != null;
  }

  public int hashCode() {
    return Objects.hash(name, dimensions);
  }

  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (!(name == null)) {
      sb.append("name:");
      sb.append(name);
      sb.append(",");
    }
    sb.append("dimensions:");
    sb.append(dimensions);
    sb.append("}");
    return sb.toString();
  }

  public A withDimensions(int dimensions) {
    this.dimensions = dimensions;
    return (A) this;
  }

  public A withName(String name) {
    this.name = name;
    return (A) this;
  }

}
